@@ -1,6 +1,22 @@
 #' @export
 generics::tidy
 
+#' @inherit generics::tidy
+#'
+#' @export
+tidy.mcmc <- function(x, ...) {
+  chk_unused(...)
+  tidy(as_nlists(x))
+}
+
+#' @inherit generics::tidy
+#'
+#' @export
+tidy.mcmc.list <- function(x, ...) {
+  chk_unused(...)
+  tidy(as_nlists(x))
+}
+
 #' @inherit generics::tidy
 #'
 #' @export
